package RiakSearch;

# https://wiki.basho.com/display/RIAK/Riak+Search

use strict;
use warnings;

use LWP::UserAgent;
use JSON::XS;
use Data::Dump qw/dump/;

sub new {
	my ($class, $url) = @_;

	my $ua = LWP::UserAgent->new;
	$ua->timeout(10);
	$ua->env_proxy;

	return bless {
		ua  => $ua,
		url => $url,
		args => '',
	}, $class;
}

sub request {
	my ($self, $method, $uri, $content, $headers) = @_;

	my $full_url = $self->{url} . "/riak/$uri";
	$full_url =~ s{//+}{/}g;
	$full_url =~ s{http:/}{http://};
	$full_url .= '?' . $self->{args} if $self->{args};

	$headers->{'Content-Type'} = 'application/json' unless exists $headers->{'Content-Type'};
	$headers->{'Host'} = $1 if $full_url =~ m{http://([^/]+)};

	my $req;

	if (defined $content) {
		$content = encode_json $content if ref $content;
		$req = HTTP::Request->new( $method, $full_url, undef, $content );
	} else {
		$req = HTTP::Request->new( $method, $full_url );
	}

	$req->header( $_ => $headers->{$_} ) foreach keys %$headers;

#	warn "## $method $full_url ", dump($req, $content);
	my $response = $self->{ua}->request($req);

	warn "$method $full_url ", $response->status_line,$/;

	if ($response->is_success) {
		#return $response->content;
	} else {
		warn "## header,content ",dump( $headers, $content );
		die $response->status_line . ":" . $response->content;
	}
}

1;
